@@ -2,30 +2,31 @@
 use common::sense;
 
 use AnyEvent;
-use AnyEvent::Util;
-use Benchmark qw(cmpthese);
+use Benchmark qw(cmpthese :hireswallclock);
 use File::Slurp;
 use File::Temp;
 use List::Util qw(shuffle);
-use POSIX;
+use Parallel::ForkManager;
 
 use AnyEvent::Curl::Multi;
-use AnyEvent::HTTP;
 use AnyEvent::Net::Curl::Queued;
 use AnyEvent::Net::Curl::Queued::Easy;
 use HTTP::Lite;
+use HTTP::Request::Common qw(GET);
 use HTTP::Tiny;
 use LWP::Curl;
 use LWP::UserAgent;
+use Parallel::Downloader;
 use WWW::Mechanize;
 
-my $parallel = $AnyEvent::Util::MAX_FORKS;
+my $parallel = 4;
 my @urls = read_file('queue', 'chomp' => 1);
 my $num = scalar @urls;
 for (my $i = 0; $i < $num; $i++) {
     push @urls, $urls[$i] . "?$_" for 1 .. 5;
 }
 @urls = shuffle @urls;
+#splice @urls, 1000;
 say STDERR scalar @urls;
 
 my (
@@ -64,132 +65,103 @@ cmpthese(10 => {
         system qw(lftp -f), $lftp_queue->filename;
     },
     '01-wget' => sub {
-        my $cv = AE::cv;
+        my $pm = Parallel::ForkManager->new($parallel);
         for my $list (@wget_queue) {
-            $cv->begin;
-            fork_call {
-                system qw(wget -q -O /dev/null -i), $list->filename;
-            } sub {
-                $cv->end;
-            }
+            my $pid = $pm->start and next;
+            system qw(wget -q -O /dev/null -i), $list->filename;
+            $pm->finish;
         }
-        $cv->wait;
+        $pm->wait_all_children;
     },
     '02-curl' => sub {
-        my $cv = AE::cv;
+        my $pm = Parallel::ForkManager->new($parallel);
         for my $list (@curl_queue) {
-            $cv->begin;
-            fork_call {
-                system qw(curl -s -K), $list->filename;
-            } sub {
-                $cv->end;
-            }
+            my $pid = $pm->start and next;
+            system qw(curl -s -K), $list->filename;
+            $pm->finish;
         }
-        $cv->wait;
+        $pm->wait_all_children;
     },
 
     # non-async modules
     '10-HTTP::Lite' => sub {
-        my $cv = AE::cv;
         my $ua = HTTP::Lite->new;
+        my $pm = Parallel::ForkManager->new($parallel);
         for my $queue (@queue) {
-            $cv->begin;
-            fork_call {
-                for my $url (@{$queue}) {
-                    $ua->request($url);
-                }
-            } sub {
-                $cv->end;
-            };
+            my $pid = $pm->start and next;
+            for my $url (@{$queue}) {
+                $ua->request($url);
+            }
+            $pm->finish;
         }
-        $cv->wait;
+        $pm->wait_all_children;
     },
     '11-HTTP::Tiny' => sub {
-        my $cv = AE::cv;
         my $ua = HTTP::Tiny->new;
+        my $pm = Parallel::ForkManager->new($parallel);
         for my $queue (@queue) {
-            $cv->begin;
-            fork_call {
-                for my $url (@{$queue}) {
-                    $ua->get($url);
-                }
-            } sub {
-                $cv->end;
-            };
+            my $pid = $pm->start and next;
+            for my $url (@{$queue}) {
+                $ua->get($url);
+            }
+            $pm->finish;
         }
-        $cv->wait;
+        $pm->wait_all_children;
     },
     '12-LWP::UserAgent' => sub {
-        my $cv = AE::cv;
         my $ua = LWP::UserAgent->new;
+        my $pm = Parallel::ForkManager->new($parallel);
         for my $queue (@queue) {
-            $cv->begin;
-            fork_call {
-                for my $url (@{$queue}) {
-                    $ua->get($url);
-                }
-            } sub {
-                $cv->end;
-            };
+            my $pid = $pm->start and next;
+            for my $url (@{$queue}) {
+                $ua->get($url);
+            }
+            $pm->finish;
         }
-        $cv->wait;
+        $pm->wait_all_children;
     },
     '13-WWW::Mechanize' => sub {
-        my $cv = AE::cv;
         my $ua = WWW::Mechanize->new;
+        my $pm = Parallel::ForkManager->new($parallel);
         for my $queue (@queue) {
-            $cv->begin;
-            fork_call {
-                for my $url (@{$queue}) {
-                    $ua->get($url);
-                }
-            } sub {
-                $cv->end;
-            };
+            my $pid = $pm->start and next;
+            for my $url (@{$queue}) {
+                $ua->get($url);
+            }
+            $pm->finish;
         }
-        $cv->wait;
+        $pm->wait_all_children;
     },
     '14-LWP::Curl' => sub {
-        my $cv = AE::cv;
         my $ua = LWP::Curl->new;
+        my $pm = Parallel::ForkManager->new($parallel);
         for my $queue (@queue) {
-            $cv->begin;
-            fork_call {
-                for my $url (@{$queue}) {
-                    $ua->get($url);
-                }
-            } sub {
-                $cv->end;
-            };
+            my $pid = $pm->start and next;
+            for my $url (@{$queue}) {
+                $ua->get($url);
+            }
+            $pm->finish;
         }
-        $cv->wait;
+        $pm->wait_all_children;
     },
 
     # async modules
-    '20-AnyEvent::HTTP' => sub {
-        my $cv = AE::cv;
-        my $i = 0;
-
-        my $get;
-        $get = sub {
-            $cv->begin;
-            http_get $urls[$i++], sub {
-                $get->() if $i <= $#urls;
-                $cv->end;
-            };
-        };
-
-        for (1 .. $parallel) {
-            $get->();
-        }
-        $cv->wait;
+    '20-Parallel::Downloader' => sub {
+        my $downloader = Parallel::Downloader->new(
+            requests        => [ map { GET($_) } @urls ],
+            workers         => $parallel,
+            conns_per_host  => $parallel,
+        );
+        $downloader->run;
     },
     '21-AnyEvent::Net::Curl::Queued' => sub {
-        my $q = AnyEvent::Net::Curl::Queued->new({ max => $parallel });
+        my $yada = AnyEvent::Net::Curl::Queued->new({ max => $parallel });
         for my $url (@urls) {
-            $q->append(sub { AnyEvent::Net::Curl::Queued::Easy->new({ initial_url => $url }) });
+            $yada->append(sub {
+                AnyEvent::Net::Curl::Queued::Easy->new({ initial_url => $url })
+            });
         }
-        $q->wait;
+        $yada->wait;
     },
     '22-AnyEvent::Curl::Multi' => sub {
         my $cv = AE::cv;
